@@ -46,14 +46,14 @@ class DmlHelper(RelationalDbHelper):
             elif operator == "IN":
                 # 依据字段数组织占位符
                 placeholder_str = ','.join('?' for v in range(len(value)))
-                sql_segment = f'"{column}" IN ({placeholder_str})'
+                sql_segment = f'{column} IN ({placeholder_str})'
             elif operator == "NOT_IN":
                 # 依据字段数组织占位符
                 placeholder_str = ','.join('?' for v in range(len(value)))
-                sql_segment = f'"{column}" NOT IN ({placeholder_str})'
+                sql_segment = f'{column} NOT IN ({placeholder_str})'
             else:
                 # 操作符号不需要转码的
-                sql_segment = f'"{column}" {operator} ?'
+                sql_segment = f'{column} {operator} ?'
             if condition_sql:
                 condition_sql = f"{condition_sql} {connector} {sql_segment}"
             else:
@@ -78,13 +78,13 @@ class DmlHelper(RelationalDbHelper):
                 condition_wrapper.column.remove("*")
                 flag = True
             else:
-                column_str = ','.join([f'"{_}"' for _ in condition_wrapper.column])
+                column_str = ','.join([f'{_}' for _ in condition_wrapper.column])
             if flag:
                 if column_str:
                     column_str += ",*"
                 else:
                     column_str = "*"
-        sql = f'SELECT {column_str} FROM "{condition_wrapper.table}" '
+        sql = f'SELECT {column_str} FROM {condition_wrapper.table}'
         condition_sql, values = self.prepare_condition_sql(condition_wrapper.conditions)
         # 拼接 条件SQL
         if condition_sql:
@@ -120,7 +120,7 @@ class DmlHelper(RelationalDbHelper):
                 placeholder_items.append("?")
         placeholder_str = ','.join(placeholder_items)
         # 组装可执行SQL
-        insert_sql = f'INSERT INTO "{table_name}" ({column_str}) VALUES ({placeholder_str})'
+        insert_sql = f'INSERT INTO {table_name} ({column_str}) VALUES ({placeholder_str})'
         return insert_sql
 
     def prepare_update_sql(self, condition_wrapper: ConditionWrapper, param: dict):
@@ -142,7 +142,7 @@ class DmlHelper(RelationalDbHelper):
                 value_items.append(v)
         column_sql = ','.join(placeholder_items)
         condition_sql, values = self.prepare_condition_sql(condition_wrapper.conditions)
-        update_sql = f'UPDATE "{condition_wrapper.table}" SET {column_sql} WHERE {condition_sql}'
+        update_sql = f'UPDATE {condition_wrapper.table} SET {column_sql} WHERE {condition_sql}'
         return update_sql, value_items + values
 
     def prepare_delete_sql(self, condition_wrapper: ConditionWrapper):
@@ -152,7 +152,7 @@ class DmlHelper(RelationalDbHelper):
         :return:
         """
         condition_sql, values = self.prepare_condition_sql(condition_wrapper.conditions)
-        delete_sql = f'DELETE FROM "{condition_wrapper.table}" WHERE {condition_sql}'
+        delete_sql = f'DELETE FROM {condition_wrapper.table} WHERE {condition_sql}'
         return delete_sql, values
 
     """
@@ -308,7 +308,7 @@ class DmlHelper(RelationalDbHelper):
                 cols.remove("*")
                 flag = True
             else:
-                column_str = ','.join([f'"{_}"' for _ in cols])
+                column_str = ','.join([f'{_}' for _ in cols])
             if flag:
                 if column_str:
                     column_str += ",*"
@@ -316,7 +316,7 @@ class DmlHelper(RelationalDbHelper):
                     column_str = "*"
 
         # 组装分页查询语句，需要依据页码计算 起始索引
-        page_sql = f"SELECT {column_str} FROM ({query_sql}) cs LIMIT {Page.skip(page_num, page_size)},{page_size}"
+        page_sql = f"SELECT {','.join(cols)} FROM ({query_sql}) cs LIMIT {Page.skip(page_num, page_size)},{page_size}"
         # 组装查询数量语句
         count_sql = f"SELECT count(1) total FROM ({query_sql}) cs"
         return page_sql, values, count_sql
