@@ -258,16 +258,16 @@ class BaseHandler(RequestHandler):
             try:
                 if inspect.iscoroutinefunction(handler_method):
                     # data = await handler_method(*params_list)
-                    if options.common_cache_enable:
-                        data = await async_common_cache(handler_method, options.common_cache_ex, **params_dict)
+                    if options.global_cache_enable:
+                        data = await async_common_cache(handler_method, options.global_cache_ex, **params_dict)
                     else:
                         data = await handler_method(**params_dict)
 
                 else:
                     # 阻塞方法异步调用
                     # data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-                    if options.common_cache_enable:
-                        func = lambda: common_cache(handler_method, options.common_cache_ex, **params_dict)
+                    if options.global_cache_enable:
+                        func = lambda: common_cache(handler_method, options.global_cache_ex, **params_dict)
                     else:
                         func = lambda: handler_method(**params_dict)
                     data = await IOLoop.current().run_in_executor(None, func)
